macro_rules! css_once {
($css:ident, $($str:tt)+) => { ... };
}Expand description
A macro for the Markup templates to ensure the css is rendered only once
macro_rules! css_once {
($css:ident, $($str:tt)+) => { ... };
}A macro for the Markup templates to ensure the css is rendered only once